@@ -1,3 +1,26 @@
+"""
+## Amazon SageMaker Construct Library
+
+<html></html>---
+
+
+![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
+
+> **This is a *developer preview* (public beta) module. Releases might lack important features and might have
+> future breaking changes.**
+>
+> This API is still under active development and subject to non-backward
+> compatible changes or removal in any future version. Use of the API is not recommended in production
+> environments. Experimental APIs are not subject to the Semantic Versioning model.
+
+---
+<html></html>
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+sagemaker = require("@aws-cdk/aws-sagemaker")
+```
+"""
 import abc
 import datetime
 import enum
@@ -10,7 +33,8 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sagemaker", "1.14.0", __name__, "aws-sagemaker@1.14.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sagemaker", "1.17.0", __name__, "aws-sagemaker@1.17.0.jsii.tgz")
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnCodeRepository(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnCodeRepository"):
     """A CloudFormation ``AWS::SageMaker::CodeRepository``.
 
@@ -32,6 +56,17 @@ class CfnCodeRepository(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
         jsii.create(CfnCodeRepository, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -186,6 +221,7 @@ class CfnCodeRepositoryProps():
         return 'CfnCodeRepositoryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnEndpoint"):
     """A CloudFormation ``AWS::SageMaker::Endpoint``.
 
@@ -208,6 +244,17 @@ class CfnEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
         jsii.create(CfnEndpoint, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -274,6 +321,7 @@ class CfnEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.set(self, "endpointName", value)
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnEndpointConfig"):
     """A CloudFormation ``AWS::SageMaker::EndpointConfig``.
 
@@ -297,6 +345,17 @@ class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
         jsii.create(CfnEndpointConfig, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -585,6 +644,7 @@ class CfnEndpointProps():
         return 'CfnEndpointProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnModel(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnModel"):
     """A CloudFormation ``AWS::SageMaker::Model``.
 
@@ -610,6 +670,17 @@ class CfnModel(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
         jsii.create(CfnModel, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -914,6 +985,7 @@ class CfnModelProps():
         return 'CfnModelProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnNotebookInstance(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnNotebookInstance"):
     """A CloudFormation ``AWS::SageMaker::NotebookInstance``.
 
@@ -947,6 +1019,17 @@ class CfnNotebookInstance(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
         jsii.create(CfnNotebookInstance, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -1167,6 +1250,7 @@ class CfnNotebookInstance(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         return jsii.set(self, "volumeSizeInGb", value)
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnNotebookInstanceLifecycleConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnNotebookInstanceLifecycleConfig"):
     """A CloudFormation ``AWS::SageMaker::NotebookInstanceLifecycleConfig``.
 
@@ -1189,6 +1273,17 @@ class CfnNotebookInstanceLifecycleConfig(aws_cdk.core.CfnResource, metaclass=jsi
 
         jsii.create(CfnNotebookInstanceLifecycleConfig, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -1522,6 +1617,7 @@ class CfnNotebookInstanceProps():
         return 'CfnNotebookInstanceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnWorkteam(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteam"):
     """A CloudFormation ``AWS::SageMaker::Workteam``.
 
@@ -1546,6 +1642,17 @@ class CfnWorkteam(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
         jsii.create(CfnWorkteam, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
